.. highlight: yaml
   :linenothreshold: 5

.. _feature_guide:

======================
Guideline for features
======================

Here are guideline for features:

.. toctree::
   :maxdepth: 2

   multi-clouds
